.. _design_phases:

Design Phases - ``ORBIT.phases.design``
=============================================

ORBIT includes the following design modules that can be used within
ProjectManager. These design processes are intended to broadly capture scaling
trends but are not intended to be used for actual designs.

.. toctree::
   :maxdepth: 2

   phases/design/api_MonopileDesign
   phases/design/api_ScourProtectionDesign
   phases/design/api_ArraySystemDesign
   phases/design/api_ExportSystemDesign
   phases/design/api_ElectricalDesign
   phases/design/api_OffshoreSubstationDesign
   phases/design/api_SemiSubmersibleDesign
   phases/design/api_SparDesign
   phases/design/api_MooringSystemDesign
